==> catoriseplus_0.5.0.orig.tar.gz: catoriseplus-0.5.0.orig/src/entry.cpp <==
#include "mainmenu.h"
#include "entry.h"
#include <QDir>
#include <libintl.h>
#include <locale.h>

QStringList Entry::listCatoriseAvailMens;

bool catNameInsensitive(const QString &s1, const QString &s2) {
    QString s1o = "ai_category_"+s1;
    QString s2o = "ai_category_"+s2;
    QString s1n = ( QString::fromLocal8Bit(gettext(s1o.toUtf8()) ) ).trimmed();
    QString s2n = ( QString::fromLocal8Bit(gettext(s2o.toUtf8()) ) ).trimmed();
    QString s1nn, s2nn;

    if (s1o != s1n) {
        s1nn = s1n;
    }
    else {
        s1nn = s1;
    }
    if (s2o != s2n) {
        s2nn = s2n;
    }
    else {
        s2nn = s2;
    }

    return s1nn.toLower() < s2nn.toLower();
}

Entry::Entry(){

}

void Entry::CreateList() {
    QDir dir("/opt/catorise/share");
    dir.setFilter(QDir::Files);
    dir.setSorting(QDir::Name);
    Entry::listCatoriseAvailMens.clear();

    if (!dir.exists()) {
        qWarning("Can't find catorise category");
    }
    else {
        QStringList list = dir.entryList();
        for (int i = 0; i < list.size(); i++) {
            // get fileName without .directory and so...
            QRegExp rx("(.+)\\.directory");
            rx.indexIn(list.at(i));
            QString fileNameFound = rx.cap(1);
            Entry::listCatoriseAvailMens << fileNameFound;
        }
        // Sort
        qSort(Entry::listCatoriseAvailMens.begin(), Entry::listCatoriseAvailMens.end(), catNameInsensitive);
    }
}

void Entry::setName(QString name){
    this->name = name;
}

void Entry::setDesktopName(QString desktopName){
    this->desktopName = desktopName;
}

void Entry::setIconPath(QString iconPath){
    this->iconPath = iconPath;
}

void Entry::setTextDomain(QString textDomain){
    this->textDomain = textDomain;
}

void Entry::setActualCategory(QString category){
    this->actualCategory = category;
}

QString Entry::getName(){
    return this->name;
}

QString Entry::getDesktopName(){
    return this->desktopName;
}

QString Entry::getIconPath(){
    return this->iconPath;
}

QString Entry::getTextDomain(){
    return this->textDomain;
}

QString Entry::getActualCategory(){
    return this->actualCategory;
}

void Entry::changedCategory(int index){
    this->setActualCategory(Entry::listCatoriseAvailMens.at(index));
}

==> catoriseplus_0.5.2.orig.tar.gz: catoriseplus-0.5.2.orig/src/entry.cpp <==
#include "mainmenu.h"
#include "entry.h"
#include <QDir>
#include <libintl.h>
#include <locale.h>

QStringList Entry::listCatoriseAvailMens;

bool catNameInsensitive(const QString &s1, const QString &s2) {
    
        QString s1o = "ai_category_"+s1;
        QString s2o = "ai_category_"+s2;
        QString s1n = ( QString::fromLocal8Bit(gettext(s1o.toUtf8()) ) ).trimmed();
        QString s2n = ( QString::fromLocal8Bit(gettext(s2o.toUtf8()) ) ).trimmed();
        QString s1nn, s2nn;

        if (s1o != s1n) {
            s1nn = s1n;
        }
        else {
            s1nn = s1;
        }
        if (s2o != s2n) {
            s2nn = s2n;
        }
        else {
            s2nn = s2;
        }

        return s1nn.toLower() < s2nn.toLower();
    
}

Entry::Entry(){

}

void Entry::CreateList() {
    QDir dir("/opt/catorise/share");
    dir.setFilter(QDir::Files);
    dir.setSorting(QDir::Name);
    Entry::listCatoriseAvailMens.clear();

    if (!dir.exists()) {
        qWarning("Can't find catorise category");
    }
    else {
        QStringList list = dir.entryList();
        Entry::listCatoriseAvailMens << "No Category";
        for (int i = 0; i < list.size(); i++) {
            // get fileName without .directory and so...
            QRegExp rx("(.+)\\.directory");
            rx.indexIn(list.at(i));
            QString fileNameFound = rx.cap(1);
            Entry::listCatoriseAvailMens << fileNameFound;
        }
        // Sort
        qSort(Entry::listCatoriseAvailMens.begin()+1, Entry::listCatoriseAvailMens.end(), catNameInsensitive);
    }
}

void Entry::setName(QString name){
    this->name = name;
}

void Entry::setDesktopName(QString desktopName){
    this->desktopName = desktopName;
}

void Entry::setIconPath(QString iconPath){
    this->iconPath = iconPath;
}

void Entry::setTextDomain(QString textDomain){
    this->textDomain = textDomain;
}

void Entry::setActualCategory(QString category){
    this->actualCategory = category;
}

QString Entry::getName(){
    return this->name;
}

QString Entry::getDesktopName(){
    return this->desktopName;
}

QString Entry::getIconPath(){
    return this->iconPath;
}

QString Entry::getTextDomain(){
    return this->textDomain;
}

QString Entry::getActualCategory(){
    return this->actualCategory;
}

void Entry::changedCategory(int index){
    this->setActualCategory(Entry::listCatoriseAvailMens.at(index));
}
